@@ -14,7 +14,7 @@ from django.utils.encoding import force_str
 
 from drf_openapi3.settings import RemovedInDRF313Warning, RemovedInDRF314Warning
 from rest_framework import (
-    RemovedInDRF314Warning, exceptions, renderers, serializers
+    exceptions, renderers, serializers
 )
 from rest_framework.compat import uritemplate
 from rest_framework.fields import _UnvalidatedField, empty
